@@ -1,5 +1,6 @@
 import asyncio
 import contextlib
+import os
 import typing
 
 import asyncpg
@@ -7,7 +8,10 @@ from pg_sql import SqlObject, sql_list
 
 Snapshot = str
 
-Tid = [int, int]
+
+def server_settings():
+    application_name = os.environ.get("PGAPPNAME", "slice_db")
+    server_settings = {"application_name": application_name}
 
 
 @contextlib.asynccontextmanager
@@ -15,7 +19,7 @@ async def connection_manager(connection: asyncpg.Connection):
     try:
         yield connection
     finally:
-        connection.close()
+        await connection.close()
 
 
 async def export_snapshot(conn: asyncpg.Connection) -> Snapshot:
@@ -23,7 +27,8 @@ async def export_snapshot(conn: asyncpg.Connection) -> Snapshot:
 
 
 async def set_snapshot(conn: asyncpg.Connection, snapshot: Snapshot):
-    await conn.execute("SET TRANSACTION SNAPSHOT $1", [snapshot])
+    # TODO: properly interpolate
+    await conn.execute(f"SET TRANSACTION SNAPSHOT '{snapshot}'")
 
 
 async def defer_constraints(conn: asyncpg.Connection, names: typing.List[SqlObject]):
@@ -31,16 +36,19 @@ async def defer_constraints(conn: asyncpg.Connection, names: typing.List[SqlObje
     await conn.execute(query)
 
 
-def int_to_tid(int: int) -> Tid:
-    a = int // (2 ** (4 * 8))
-    b = int % (2 ** (4 * 8))
-    return a, b
+def tid_decoder(bytes: bytes) -> int:
+    return int.from_bytes(bytes, "big")
 
 
-def tid_to_int(id: Tid) -> int:
-    """
-    Translate TID to 48-bit integer, where 32 top significant bits are block number,
-    and the other 16 bits are the position within the block
-    """
-    a, b = id
-    return a * (2 ** (4 * 8)) + b
+def tid_encoder(int: int) -> bytes:
+    return int.to_bytes(6, "big")
+
+
+async def set_tid_codec(conn: asyncpg.Connection):
+    await conn.set_type_codec(
+        "tid",
+        schema="pg_catalog",
+        encoder=tid_encoder,
+        decoder=tid_decoder,
+        format="binary",
+    )
